@@ -1,11 +1,12 @@
 # -------------------------------------------------------------------------------
-# Copyright 2006-2020 UT-Battelle, LLC. See LICENSE for more information.
+# Copyright 2006-2021 UT-Battelle, LLC. See LICENSE for more information.
 # -------------------------------------------------------------------------------
 import os
 import sys
 import importlib
 import importlib.util
 import tempfile
+import uuid
 import logging
 import socket
 from multiprocessing import Queue, Process, set_start_method
@@ -87,8 +88,8 @@ class ConfigurationManager:
                 self.stream.write(data)
                 self.stream.flush()
 
-            def writelines(self, datas):
-                self.stream.writelines(datas)
+            def writelines(self, data):
+                self.stream.writelines(data)
                 self.stream.flush()
 
             def __getattr__(self, attr):
@@ -291,7 +292,7 @@ class ConfigurationManager:
             new_sim.conf_file_dir = os.path.dirname(os.path.abspath(conf_file))
             new_sim.sim_root = sim_root
             new_sim.log_file = log_file
-            new_sim.log_pipe_name = tempfile.mktemp('.logpipe', 'ips_')
+            new_sim.log_pipe_name = f'{tempfile.gettempdir()}/ips_{uuid.uuid4()}.logpipe'
 
             self.log_daemon.add_sim_log(new_sim.log_pipe_name,
                                         new_sim.log_file)
@@ -305,7 +306,7 @@ class ConfigurationManager:
                 fwk_sim.sim_conf = fwk_sim_conf
                 fwk_sim.sim_root = new_sim.sim_root
                 fwk_sim.log_file = self.fwk.log_file  # sys.stdout
-                fwk_sim.log_pipe_name = tempfile.mktemp('.logpipe', 'ips_')
+                fwk_sim.log_pipe_name = f'{tempfile.gettempdir()}/ips_{uuid.uuid4()}.logpipe'
                 fwk_sim_conf['LOG_LEVEL'] = 'DEBUG'
                 self.log_daemon.add_sim_log(fwk_sim.log_pipe_name, fwk_sim.log_file)
                 self.fwk_sim_name = fwk_sim_conf['SIM_NAME']
@@ -353,7 +354,7 @@ class ConfigurationManager:
                                                        self.sim_map[self.fwk_sim_name])
         self.fwk_components.append(runspace_component_id)
 
-        # SIMYAN: set up The Portal bridge, allowing for an absense of a portal
+        # SIMYAN: set up The Portal bridge, allowing for an absence of a portal
         use_portal = True
         if 'USE_PORTAL' in self.sim_map[self.fwk_sim_name].sim_conf:
             use_portal = self.sim_map[self.fwk_sim_name].sim_conf['USE_PORTAL']
@@ -545,8 +546,7 @@ class ConfigurationManager:
         return comp_list
 
     def get_all_simulation_components_map(self):
-        sim_comps = {name: self.sim_map[name].all_comps[:]
-                     for name in self.sim_map}
+        sim_comps = {name: sim_map.all_comps[:] for name, sim_map in self.sim_map.items()}
         del sim_comps[self.fwk_sim_name]
         return sim_comps
 
@@ -653,7 +653,7 @@ in configuration file %s', config_file)
         new_sim.log_file = log_file
         if not sub_workflow:
             new_sim.portal_sim_name = sim_name
-            new_sim.log_pipe_name = tempfile.mktemp('.logpipe', 'ips_')
+            new_sim.log_pipe_name = f'{tempfile.gettempdir()}/ips_{uuid.uuid4()}.logpipe'
             self.log_dynamic_sim_queue.put('CREATE_SIM  %s  %s' % (new_sim.log_pipe_name, new_sim.log_file))
         else:
             new_sim.portal_sim_name = parent_sim.portal_sim_name
