@@ -11,28 +11,10 @@ import functools
 import os
 import os.path
 import queue
-import errno
 import time
 import select
 
 
-def list_fds():
-    """List process currently open FDs and their target """
-    ret = {}
-    base = '/proc/self/fd'
-    for num in os.listdir(base):
-        path = None
-        try:
-            path = os.readlink(os.path.join(base, num))
-        except OSError as err:
-            # Last FD is always the "listdir" one (which may be closed)
-            if err.errno != errno.ENOENT:
-                raise
-        ret[int(num)] = path
-
-    return ret
-
-
 class myLogRecordStreamHandler(socketserver.StreamRequestHandler):
 
     def __init__(self, request, client_address, server, handler):
@@ -109,12 +91,11 @@ class ipsLogger:
             else:
                 directory = os.path.dirname(os.path.abspath(log_file))
                 try:
-                    os.makedirs(directory)
+                    os.makedirs(directory, exist_ok=True)
                 except OSError as oserr:
-                    if oserr.errno != 17:
-                        print('Error creating directory %s : %s-%s' %
-                              (directory, oserr.errno, oserr.strerror))
-                        sys.exit(1)
+                    print('Error creating directory %s : %s-%s' %
+                          (directory, oserr.errno, oserr.strerror))
+                    sys.exit(1)
                 log_handler = logging.FileHandler(log_file, mode='w')
 
         log_handler.setFormatter(self.formatter)
