@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------------
-# Copyright 2006-2020 UT-Battelle, LLC. See LICENSE for more information.
+# Copyright 2006-2021 UT-Battelle, LLC. See LICENSE for more information.
 # -------------------------------------------------------------------------------
 import os
 import shutil
@@ -34,8 +34,6 @@ def which(program, alt_paths=None):
                 if is_exe(exe_file):
                     return exe_file
 
-    return None
-
 
 def copyFiles(src_dir, src_file_list, target_dir, prefix='', keep_old=False):
     """
@@ -93,11 +91,10 @@ def copyFiles(src_dir, src_file_list, target_dir, prefix='', keep_old=False):
 
         (head, _) = os.path.split(os.path.abspath(target_file))
         try:
-            os.makedirs(head)
+            os.makedirs(head, exist_ok=True)
         except OSError as oserr:
-            if oserr.errno != 17:
-                print('Error creating directory %s : %s' % (head, oserr.strerror))
-                raise
+            print('Error creating directory %s : %s' % (head, oserr.strerror))
+            raise
         try:
             shutil.copy(src_file, target_file)
         except Exception:
