@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------------
-# Copyright 2006-2020 UT-Battelle, LLC. See LICENSE for more information.
+# Copyright 2006-2021 UT-Battelle, LLC. See LICENSE for more information.
 # -------------------------------------------------------------------------------
 import os
 from math import ceil
@@ -8,12 +8,9 @@ from .ipsExceptions import BlockedMessageException, \
     IncompleteCallException, \
     InsufficientResourcesException, \
     BadResourceRequestException, \
-    AllocatedNodeDownException, \
     ResourceRequestMismatchException
 from .ipsutil import which
 
-# from event_service_spec import PublisherEventService,SubscriberEventService,EventListener,Topic,EventServiceException
-
 
 class TaskManager:
     """
@@ -370,7 +367,7 @@ class TaskManager:
                             ppn_groups.update({len(cl): [n]})
                     cmdlets = []
                     envlets = []
-                    bin_n_args = binary + ' '.join(cmd_args)
+                    bin_n_args = ' '.join([binary, *cmd_args])
                     for p, ns in list(ppn_groups.items()):
                         cmdlets.append(' '.join([','.join(ns), str(p),
                                                  bin_n_args]))
@@ -388,7 +385,7 @@ class TaskManager:
                     env_update = {'MPI_DSM_CPULIST': ':'.join(envlets)}
                     return cmd, env_update
                 else:
-                    cmd = ' '.join([self.task_launch_cmd, ppn, binary,
+                    cmd = ' '.join([self.task_launch_cmd, str(ppn), binary,
                                     ' '.join(cmd_args)])
 
         # --------------------------------------
@@ -621,9 +618,6 @@ class TaskManager:
         try:
             self.resource_mgr.release_allocation(task_id, task_data)
             del self.curr_task_table[task_id]
-        except AllocatedNodeDownException:
-            del self.curr_task_table[task_id]
-            return 1
         except Exception:
             print('Error finishing task ', task_id)
             raise
